@@ -1,4 +1,4 @@
-#Visualize module for plotting and handling predictions
+# Visualize module for plotting and handling predictions
 import os
 import pandas as pd
 import matplotlib
@@ -7,7 +7,8 @@ import matplotlib.patches as patches
 from skimage import io
 import numpy as np
 
-def format_boxes(prediction, scores = True):
+
+def format_boxes(prediction, scores=True):
     """Format a retinanet prediction into a pandas dataframe for a single image
        Args:
            prediction: a dictionary with keys 'boxes' and 'labels' coming from a retinanet
@@ -15,34 +16,38 @@ def format_boxes(prediction, scores = True):
         Returns:
            df: a pandas dataframe
     """
-            
-    df = pd.DataFrame(prediction["boxes"].cpu().detach().numpy(),columns=["xmin","ymin","xmax","ymax"])
+
+    df = pd.DataFrame(prediction["boxes"].cpu().detach().numpy(),
+                      columns=["xmin", "ymin", "xmax", "ymax"])
     df["label"] = prediction["labels"].cpu().detach().numpy()
-    
+
     if scores:
         df["scores"] = prediction["scores"].cpu().detach().numpy()
-    
-    return df 
+
+    return df
+
 
 def plot_prediction_and_targets(image, predictions, targets, image_name, savedir):
     """Plot an image, its predictions, and its ground truth targets for debugging"""
     prediction_df = format_boxes(predictions)
     plot, ax = plot_predictions(image, prediction_df)
-    target_df = format_boxes(targets, scores=False)    
+    target_df = format_boxes(targets, scores=False)
     plot = add_annotations(plot, ax, target_df)
-    plot.savefig("{}/{}.png".format(savedir,image_name))  
-    return "{}/{}.png".format(savedir,image_name)
+    plot.savefig("{}/{}.png".format(savedir, image_name))
+    return "{}/{}.png".format(savedir, image_name)
+
 
 def plot_prediction_dataframe(df, ground_truth, root_dir, savedir=None):
     """For each row in dataframe, call plot predictions"""
     for name, group in df.groupby("image_path"):
-        image = io.imread("{}/{}".format(root_dir,name))
+        image = io.imread("{}/{}".format(root_dir, name))
         plot, ax = plot_predictions(image, group)
-        annotations = ground_truth[ground_truth.image_path==name]
+        annotations = ground_truth[ground_truth.image_path == name]
         plot = add_annotations(plot, ax, annotations)
         if savedir:
-            plot.savefig("{}/{}.png".format(savedir,os.path.splitext(name)[0]))    
-        
+            plot.savefig("{}/{}.png".format(savedir, os.path.splitext(name)[0]))
+
+
 def plot_predictions(image, df):
     """channel order is channels first for pytorch"""
     fig, ax = plt.subplots()
@@ -53,22 +58,24 @@ def plot_predictions(image, df):
         width = row["xmax"] - xmin
         height = row["ymax"] - ymin
         color = label_to_color(row["label"])
-        rect = create_box(xmin=xmin,ymin=ymin, height=height, width=width,color=color)
+        rect = create_box(xmin=xmin, ymin=ymin, height=height, width=width, color=color)
         ax.add_patch(rect)
-    #no axis show up
+    # no axis show up
     plt.axis('off')
 
     return fig, ax
-        
-def create_box(xmin, ymin, height, width, color="cyan",linewidth=1):
-    rect = patches.Rectangle((xmin,ymin),
-                     height,
-                     width,
-                     linewidth=linewidth,
-                     edgecolor=color,
-                     fill = False)
+
+
+def create_box(xmin, ymin, height, width, color="cyan", linewidth=1):
+    rect = patches.Rectangle((xmin, ymin),
+                             height,
+                             width,
+                             linewidth=linewidth,
+                             edgecolor=color,
+                             fill=False)
     return rect
 
+
 def add_annotations(plot, ax, annotations):
     """Add annotations to an already created visuale.plot_predictions
     Args:
@@ -83,18 +90,26 @@ def add_annotations(plot, ax, annotations):
         ymin = row["ymin"]
         width = row["xmax"] - xmin
         height = row["ymax"] - ymin
-        rect = create_box(xmin=xmin,ymin=ymin, height=height, width=width, color="orange")
-        ax.add_patch(rect) 
-    
+        rect = create_box(xmin=xmin,
+                          ymin=ymin,
+                          height=height,
+                          width=width,
+                          color="orange")
+        ax.add_patch(rect)
+
     return plot
 
+
 def label_to_color(label):
     color_dict = {}
-    colors = [list((matplotlib.colors.hsv_to_rgb([x, 1.0, 1.0])).astype(int)) for x in np.arange(0, 1, 1.0 / 80)]
+    colors = [
+        list((matplotlib.colors.hsv_to_rgb([x, 1.0, 1.0])).astype(int))
+        for x in np.arange(0, 1, 1.0 / 80)
+    ]
     for index, color in enumerate(colors):
         color_dict[index] = color
-    
-    #hand pick the first few colors
+
+    # hand pick the first few colors
     color_dict[0] = "cyan"
     color_dict[1] = "tomato"
     color_dict[2] = "blue"
@@ -105,5 +120,5 @@ def label_to_color(label):
     color_dict[7] = "dodgerblue"
     color_dict[8] = "gold"
     color_dict[9] = "blueviolet"
-    
+
     return color_dict[label]
